@@ -1,12 +1,17 @@
 import json
 
+from django.core.cache import cache
 from django.http import HttpResponse
 from django.shortcuts import get_object_or_404
+from django.utils.decorators import method_decorator
+from django.views.decorators.cache import cache_page
 from large_image.tilesource import FileTileSource
 from large_image_source_gdal import GDALFileTileSource
 from rest_framework.request import Request
 from rest_framework.response import Response
 from rest_framework.views import APIView
+from rgd.rest import CACHE_TIMEOUT
+from rgd.rest.authentication import SignedURLAuthentication
 from rgd.rest.mixins import BaseRestViewMixin
 from rgd_imagery import large_image_utilities
 from rgd_imagery.models import Image
@@ -15,8 +20,19 @@ from rgd_imagery.models import Image
 class BaseTileView(BaseRestViewMixin, APIView):
     def get_tile_source(self, request: Request, pk: int) -> FileTileSource:
         """Return the built tile source."""
-        image_entry = get_object_or_404(Image, pk=pk)
-        self.check_object_permissions(request, image_entry)
+        # get image_entry from cache
+        image_cache_key = f'large_image_tile:image_{pk}'
+        if (image_entry := cache.get(image_cache_key, None)) is None:
+            image_entry = get_object_or_404(Image.objects.select_related('file'), pk=pk)
+            cache.set(image_cache_key, image_entry, CACHE_TIMEOUT)
+
+        # check authentication
+        sentinel = object()
+        auth_cache_key = f'large_image_tile:image_{pk}:user_{request.user.pk}'
+        if cache.get(auth_cache_key, sentinel) is sentinel:
+            self.check_object_permissions(request, image_entry)
+            cache.set(auth_cache_key, None, CACHE_TIMEOUT)
+
         projection = request.query_params.get('projection', None)
         band = int(request.query_params.get('band', 0))
         style = None
@@ -28,6 +44,12 @@ class BaseTileView(BaseRestViewMixin, APIView):
                 style['min'] = bmin
             if bmax is not None:
                 style['max'] = bmax
+            palette = request.query_params.get('palette', None)
+            if palette:
+                style['palette'] = palette
+            nodata = request.query_params.get('nodata', None)
+            if nodata:
+                style['nodata'] = nodata
             style = json.dumps(style)
         return large_image_utilities.get_tilesource_from_image(image_entry, projection, style=style)
 
@@ -53,6 +75,11 @@ class TileInternalMetadataView(BaseTileView):
 class TileView(BaseTileView):
     """Returns tile binary."""
 
+    authentication_classes = BaseTileView.authentication_classes + [
+        SignedURLAuthentication,
+    ]
+
+    @method_decorator(cache_page(CACHE_TIMEOUT))
     def get(self, request: Request, pk: int, x: int, y: int, z: int) -> HttpResponse:
         tile_source = self.get_tile_source(request, pk)
         tile_binary = tile_source.getTile(x, y, z)
@@ -79,6 +106,7 @@ class TileCornersView(BaseTileView):
 class TileThumnailView(BaseTileView):
     """Returns tile thumbnail."""
 
+    @method_decorator(cache_page(CACHE_TIMEOUT))
     def get(self, request: Request, pk: int) -> HttpResponse:
         tile_source = self.get_tile_source(request, pk)
         thumb_data, mime_type = tile_source.getThumbnail(encoding='PNG')
