@@ -1,8 +1,8 @@
 from rgd.views import (
     PermissionDetailView,
     PermissionTemplateView,
+    SpatialDetailView,
     SpatialEntriesListView,
-    _SpatialDetailView,
 )
 
 from . import filters, models
@@ -13,13 +13,12 @@ class ImageSetDetailView(PermissionDetailView):
 
 
 class RasterMetaEntriesListView(SpatialEntriesListView):
-    model = models.RasterMeta
-    filter = filters.RasterMetaFilter
-    context_object_name = 'spatial_entries'
+    queryset = models.RasterMeta.objects.all()
     template_name = 'rgd_imagery/rastermeta_list.html'
+    filterset_class = filters.RasterMetaFilter
 
 
-class RasterDetailView(_SpatialDetailView):
+class RasterDetailView(SpatialDetailView):
     model = models.RasterMeta
 
 
